==> qesteidutil-0.1.99.1586.tar.bz2: qesteidutil-0.1.99.1586/src/translations/et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="et_EE" sourcelanguage="en">
<context>
    <name>CertUpdate</name>
    <message>
        <source>update not allowed!</source>
        <translation>uuendamine ei ole lubatud!</translation>
    </message>
    <message>
        <source>Check internet connection</source>
        <translation>kontrollige interneti ühendust</translation>
    </message>
</context>
<context>
    <name>DiagnosticsDialog</name>
    <message>
        <source>Diagnostics</source>
        <translation>Diagnostika</translation>
    </message>
    <message>
        <source>ID-card utility version:</source>
        <translation>ID-kaardi haldusvahendi versioon:</translation>
    </message>
    <message>
        <source>Library paths:</source>
        <translation>Teegi otsing:</translation>
    </message>
    <message>
        <source>Card readers</source>
        <translation>Kaardilugejad</translation>
    </message>
    <message>
        <source>ID - %1</source>
        <translation>ID - %1</translation>
    </message>
    <message>
        <source>Error reading card data:</source>
        <translation>Kaardilt andmete lugemine ebaõnnestus:</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Teksti failid (*.txt)</translation>
    </message>
    <message>
        <source>Error occured</source>
        <translation>Tekkis viga</translation>
    </message>
    <message>
        <source>Failed write to file!</source>
        <translation>Faili kirjutamine ebaõnnestus!</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>Operatsioonisüsteem:</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Teegid</translation>
    </message>
    <message>
        <source>Smart Card service status: </source>
        <translation>Smart Card teenuse staatus:</translation>
    </message>
    <message>
        <source>PCSC service status: </source>
        <translation>PCSC teenuse staatus:</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Töötab</translation>
    </message>
    <message>
        <source>Not running</source>
        <translation>Ei tööta</translation>
    </message>
    <message>
        <source>%1 - failed to get version info</source>
        <translation>%1 - viga versiooniinfo lugemisel</translation>
    </message>
</context>
<context>
    <name>JsExtender</name>
    <message>
        <source> - %1 (active)</source>
        <translation> - %1 (aktiivne)</translation>
    </message>
    <message>
        <source> - %1 (not active)</source>
        <translation> - %1 (mitteaktiivne)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</source>
        <translation></translation>
    </message>
    <message>
        <source>Save picture</source>
        <translation>Salvesta pilt</translation>
    </message>
    <message>
        <source>Certificate update</source>
        <translation>Sertifikaatide uuendus</translation>
    </message>
    <message>
        <source>Certificate update failed: %1</source>
        <translation>Sertifikaatide uuendamine ebaõnnestus: %1</translation>
    </message>
    <message>
        <source>Certificate update not allowed!</source>
        <translation type="obsolete">Sertifikaati uuendamine ei ole lubatud!</translation>
    </message>
    <message>
        <source>Certificate update failed:&lt;br /&gt;%1</source>
        <translation>Sertifikaatide uuendamine ebaõnnestus:&lt;br /&gt;%1</translation>
    </message>
    <message>
        <source>For updating certificates please close all programs which are interacting with smartcard (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;After updating certificates it is not possible decypt documents!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>ID-card utility</source>
        <translation>ID-kaardi haldusvahend</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulge</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Check updates</source>
        <translation>Kontrolli uuendusi</translation>
    </message>
    <message>
        <source>Update automatically</source>
        <translation>Uuenda automaatselt</translation>
    </message>
    <message>
        <source>Once a day</source>
        <translation>Kord päevas</translation>
    </message>
    <message>
        <source>Once a week</source>
        <translation>Kord nädalas</translation>
    </message>
    <message>
        <source>Once a month</source>
        <translation>Kord kuus</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Mitte kunagi</translation>
    </message>
    <message>
        <source>Save PIN1 for specified period in minutes
0 - always ask</source>
        <translation>Salvesta PIN1 määratud minutiteks
0 - küsi iga kord</translation>
    </message>
</context>
</TS>

==> qesteidutil-0.1.99.1724.tar.bz2: qesteidutil-0.1.99.1724/src/translations/et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="et_EE" sourcelanguage="en">
<context>
    <name>CertUpdate</name>
    <message>
        <source>update not allowed!</source>
        <translation>uuendamine ei ole lubatud!</translation>
    </message>
    <message>
        <source>Check internet connection</source>
        <translation>kontrollige interneti ühendust</translation>
    </message>
</context>
<context>
    <name>DiagnosticsDialog</name>
    <message>
        <source>Diagnostics</source>
        <translation>Diagnostika</translation>
    </message>
    <message>
        <source>ID-card utility version:</source>
        <translation>ID-kaardi haldusvahendi versioon:</translation>
    </message>
    <message>
        <source>Library paths:</source>
        <translation>Teegi otsing:</translation>
    </message>
    <message>
        <source>Card readers</source>
        <translation>Kaardilugejad</translation>
    </message>
    <message>
        <source>ID - %1</source>
        <translation>ID - %1</translation>
    </message>
    <message>
        <source>Error reading card data:</source>
        <translation>Kaardilt andmete lugemine ebaõnnestus:</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation>Salvesta</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Teksti failid (*.txt)</translation>
    </message>
    <message>
        <source>Error occured</source>
        <translation>Tekkis viga</translation>
    </message>
    <message>
        <source>Failed write to file!</source>
        <translation>Faili kirjutamine ebaõnnestus!</translation>
    </message>
    <message>
        <source>OS:</source>
        <translation>Operatsioonisüsteem:</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Teegid</translation>
    </message>
    <message>
        <source>Smart Card service status: </source>
        <translation>Smart Card teenuse staatus:</translation>
    </message>
    <message>
        <source>PCSC service status: </source>
        <translation>PCSC teenuse staatus:</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Töötab</translation>
    </message>
    <message>
        <source>Not running</source>
        <translation>Ei tööta</translation>
    </message>
    <message>
        <source>%1 - failed to get version info</source>
        <translation>%1 - viga versiooniinfo lugemisel</translation>
    </message>
</context>
<context>
    <name>JsExtender</name>
    <message>
        <source> - %1 (active)</source>
        <translation> - %1 (aktiivne)</translation>
    </message>
    <message>
        <source> - %1 (not active)</source>
        <translation> - %1 (mitteaktiivne)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;TIFF (*.tif *.tiff);;24-bit Bitmap (*.bmp)</source>
        <translation></translation>
    </message>
    <message>
        <source>Save picture</source>
        <translation>Salvesta pilt</translation>
    </message>
    <message>
        <source>Certificate update</source>
        <translation>Sertifikaatide uuendus</translation>
    </message>
    <message>
        <source>Certificate update failed: %1</source>
        <translation>Sertifikaatide uuendamine ebaõnnestus: %1</translation>
    </message>
    <message>
        <source>Certificate update not allowed!</source>
        <translation type="obsolete">Sertifikaati uuendamine ei ole lubatud!</translation>
    </message>
    <message>
        <source>Certificate update failed:&lt;br /&gt;%1</source>
        <translation>Sertifikaatide uuendamine ebaõnnestus:&lt;br /&gt;%1</translation>
    </message>
    <message>
        <source>For updating certificates please close all programs which are interacting with smartcard (qdigidocclient, qdigidoccrypto, Firefox, Safari, Internet Explorer...)&lt;br /&gt;After updating certificates it is not possible decypt documents!</source>
        <translation>Sertifikaatite uuendamiseks palun sulgege kõik rakendused, mis kasutavad ID-kaarti (ID-kaardi klient, haldusvahend, Firefox, Safari, Internet Explorer...)&lt;br /&gt;Pärast sertifikaatide uuendamist ei ole võimalik enam dekrüpteerida vana sertifikaadiga krüpteeritud dokumente!</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>ID-card utility</source>
        <translation>ID-kaardi haldusvahend</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulge</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Check updates</source>
        <translation>Kontrolli uuendusi</translation>
    </message>
    <message>
        <source>Update automatically</source>
        <translation>Uuenda automaatselt</translation>
    </message>
    <message>
        <source>Once a day</source>
        <translation>Kord päevas</translation>
    </message>
    <message>
        <source>Once a week</source>
        <translation>Kord nädalas</translation>
    </message>
    <message>
        <source>Once a month</source>
        <translation>Kord kuus</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Mitte kunagi</translation>
    </message>
    <message>
        <source>Save PIN1 for specified period in minutes
0 - always ask</source>
        <translation>Salvesta PIN1 määratud minutiteks
0 - küsi iga kord</translation>
    </message>
</context>
</TS>
